@@ -104,7 +104,7 @@ class NaroNet:
             subject_level_labels = [i[i!='None'].values[0] if i[i!='None'].values.size!=0 else 'None' for i in subjects]
 
             # K fold cross validation or leave-one-out
-            if min([sum([1 for s in subject_level_labels if s==lbl]) for lbl in set(subject_level_labels)])<rsfk.n_splits and len(set(subject_level_labels))<5:
+            if min([sum([1 for s in subject_level_labels if s==lbl]) for lbl in set(subject_level_labels)])<self.args['folds'] and len(set(subject_level_labels))<5:
                 # Leave-one-out
                 ordered_names = [iac[0] for iac in self.IndexAndClass_reorder]
                 splitter = []
