@@ -22,23 +22,23 @@ class Dense_SAGEConv(torch.nn.Module):
         self.in_channels = in_channels
         self.out_channels = out_channels
         self.paramApply = paramApply
-        self.lin1 = torch.nn.Linear(in_channels, out_channels)#in_channels*2)        
-        # self.lin2 = torch.nn.Linear(in_channels*2, in_channels*2)        
-        # self.lin3 = torch.nn.Linear(in_channels*2, out_channels)
+        self.lin1 = torch.nn.Linear(in_channels, int(in_channels/2))#in_channels*2)        
+        self.lin2 = torch.nn.Linear(int(in_channels/2), int(in_channels/2))        
+        self.lin3 = torch.nn.Linear(int(in_channels/2), out_channels)
 
     def reset_parameters(self):
         self.lin1.reset_parameters()  
-        # self.lin2.reset_parameters()  
-        # self.lin3.reset_parameters()  
+        self.lin2.reset_parameters()  
+        self.lin3.reset_parameters()  
 
     def forward(self, x, edge_index, device, num_nodes=None):        
         
         if self.paramApply:
             x = self.lin1(x)  
-            # x = F.relu(x)  
-            # x = self.lin2(x)  
-            # x = F.relu(x)  
-            # x = self.lin3(x)  
+            x = F.relu(x)  
+            x = self.lin2(x)  
+            x = F.relu(x)  
+            x = self.lin3(x)  
             
         out = torch.zeros((x.shape),device=device)
         for i in range(len(edge_index)):
@@ -85,15 +85,15 @@ class neigh(torch.nn.Module):
         if args['n_hops_neighborhoods']==1:      
             self.conv1 = Dense_SAGEConv(in_channels, out_channels,paramApply)
         else:
-            self.conv1 = Dense_SAGEConv(in_channels, in_channels,paramApply)
+            self.conv1 = Dense_SAGEConv(in_channels, int(in_channels/2),paramApply)
         if args['n_hops_neighborhoods']==2:
-            self.conv2 = Dense_SAGEConv(in_channels, out_channels,paramApply)
+            self.conv2 = Dense_SAGEConv(int(in_channels/2), out_channels,paramApply)
         else:
-            self.conv2 = Dense_SAGEConv(in_channels, in_channels,paramApply)
+            self.conv2 = Dense_SAGEConv(int(in_channels/2), int(in_channels/2),paramApply)
         if args['n_hops_neighborhoods']==3:
-            self.conv3 = Dense_SAGEConv(in_channels, out_channels,paramApply)
+            self.conv3 = Dense_SAGEConv(int(in_channels/2), out_channels,paramApply)
         else:
-            self.conv3 = Dense_SAGEConv(in_channels, in_channels,paramApply)
+            self.conv3 = Dense_SAGEConv(int(in_channels/2), int(in_channels/2),paramApply)
        
     def reset_parameters(self):
         # First MLP into the features
@@ -157,26 +157,26 @@ class pheno(torch.nn.Module):
         self.out_channels = out_channels
 
         # Initialize linear model
-        self.lin1 = torch.nn.Linear(in_channels, out_channels)        
-        # self.lin2 = torch.nn.Linear(in_channels*2, in_channels*2)        
-        # self.lin3 = torch.nn.Linear(in_channels*2, out_channels)
+        self.lin1 = torch.nn.Linear(in_channels, int(in_channels/2))        
+        self.lin2 = torch.nn.Linear(int(in_channels/2), int(in_channels/4))        
+        self.lin3 = torch.nn.Linear(int(in_channels/4), out_channels)
         # self.BN = torch.nn.BatchNorm1d(out_channels)#,track_running_stats=False)                
 
     def reset_parameters(self):
         # Reset parameters of linear model.
         self.lin1.reset_parameters()  
-        # self.lin2.reset_parameters()  
-        # self.lin3.reset_parameters()     
+        self.lin2.reset_parameters()  
+        self.lin3.reset_parameters()     
         # self.BN = torch.nn.BatchNorm1d(self.out_channels)#,track_running_stats=False)                                           
   
     def forward(self, x, edge_index, device, num_nodes,args):    
         # Linear layer
         x = F.dropout(x, p=args['dropoutRate'], training=self.training)   
         x = self.lin1(x)  
-        # x = F.relu(x)  
-        # x = self.lin2(x)  
-        # x = F.relu(x)  
-        # x = self.lin3(x)  
+        x = F.relu(x)  
+        x = self.lin2(x)  
+        x = F.relu(x)  
+        x = self.lin3(x)  
         
         # Calculate mean and std        
         if self.training:
